@@ -597,8 +597,8 @@ private:
         {
             type = attributes.value(type_idx);
 
-            QRegExp reg_exp(QString("(a?[ybnqiuxdtsogv]|a[{]sv[}])"));
-            if (reg_exp.match(type))
+            QRegExp reg_exp(QCString("(a?[ybnqiuxdtsogv]|a[{]sv[}])"));
+            if (reg_exp.match(type.data()))
             { return type; }
 
             DOC_ERROR(QString("Unnamed complex D-Bus type \"%1\" found.").arg(type));
@@ -666,7 +666,7 @@ private:
         entry->protection = Public ;
         entry->virt       = Normal;
         entry->stat       = false;
-        entry->objc       = false;
+        entry->lang       = SrcLangExt_XML;
         entry->spec       = 0;
 
         entry->fileName  = m_fileName;
@@ -879,7 +879,8 @@ void DBusXMLScanner::parseCode(CodeOutputInterface & /* codeOutIntf */,
                                int /* startLine */,
                                int /* endLine */,
                                bool /* inlineFragment */,
-                               MemberDef * /* memberDef */)
+                               MemberDef * /* memberDef */,
+                               bool /*showLineNumbers*/)
 { }
 
 void DBusXMLScanner::resetCodeParserState()
