@@ -9,6 +9,7 @@
 #include "message.h"
 #include "dot.h"
 #include "layout.h"
+#include "ftextstream.h"
 
 //----------------------------------------------------------------------
 // method implementation
@@ -190,11 +191,12 @@ void DirDef::writeDirectoryGraph(OutputList &ol)
     {
       msg("Generating dependency graph for directory %s\n",displayName().data());
       ol.disable(OutputGenerator::Man);
-      ol.startParagraph();
+      //ol.startParagraph();
       ol.startDirDepGraph();
       //TODO: ol.parseText(theTranslator->trDirDepGraph());
+      ol.parseText((QCString)"Directory dependency graph for "+displayName()+":");
       ol.endDirDepGraph(dirDep);
-      ol.endParagraph();
+      //ol.endParagraph();
       ol.enableAll();
     }
   }
@@ -205,7 +207,7 @@ void DirDef::writeSubDirList(OutputList &ol)
   // write subdir list
   if (m_subdirs.count()>0)
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader("subdirs");
     ol.parseText(theTranslator->trDir(TRUE,FALSE));
     ol.endMemberHeader();
     ol.startMemberList();
@@ -247,7 +249,7 @@ void DirDef::writeFileList(OutputList &ol)
   // write file list
   if (m_fileList->count()>0)
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader("files");
     ol.parseText(theTranslator->trFile(TRUE,FALSE));
     ol.endMemberHeader();
     ol.startMemberList();
@@ -316,17 +318,19 @@ void DirDef::endMemberDeclarations(OutputList &ol)
 
 void DirDef::writeDocumentation(OutputList &ol)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   ol.pushGeneratorState();
   
   QCString shortTitle=theTranslator->trDirReference(m_shortName);
   QCString title=theTranslator->trDirReference(m_dispName);
-  startFile(ol,getOutputFileBase(),name(),title,HLI_None,TRUE);
+  startFile(ol,getOutputFileBase(),name(),title,HLI_None,!generateTreeView);
 
-  // write navigation path
-  writeNavigationPath(ol);
-
-  ol.endQuickIndices();
-  ol.startContents();
+  if (!generateTreeView)
+  {
+    // write navigation path
+    writeNavigationPath(ol);
+    ol.endQuickIndices();
+  }
 
   startTitle(ol,getOutputFileBase());
   ol.pushGeneratorState();
@@ -337,6 +341,7 @@ void DirDef::writeDocumentation(OutputList &ol)
     ol.parseText(title);
   ol.popGeneratorState();
   endTitle(ol,getOutputFileBase(),title);
+  ol.startContents();
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
   {
@@ -420,35 +425,18 @@ void DirDef::writeDocumentation(OutputList &ol)
     Doxygen::tagFile << "  </compound>" << endl;
   }
 
-  endFile(ol); 
-  ol.popGeneratorState();
+  ol.endContents();
 
-
-}
-
-#if 0
-void DirDef::writePathFragment(OutputList &ol) const
-{
-  if (m_parent)
+  if (generateTreeView)
   {
-    m_parent->writePathFragment(ol);
-    ol.writeString("&nbsp;/&nbsp;");
+    writeNavigationPath(ol);
   }
-  ol.writeObjectLink(getReference(),getOutputFileBase(),0,shortName());
-}
-
-void DirDef::writeNavigationPath(OutputList &ol)
-{
-  ol.pushGeneratorState();
-  ol.disableAllBut(OutputGenerator::Html);
-
-  ol.writeString("<div class=\"nav\">\n");
-  writePathFragment(ol);
-  ol.writeString("</div>\n");
 
+  endFile(ol,TRUE); 
   ol.popGeneratorState();
+
+
 }
-#endif
 
 void DirDef::setLevel()
 {
@@ -661,7 +649,7 @@ DirDef *DirDef::mergeDirectoryInTree(const QCString &path)
   return dir;
 }
 
-void DirDef::writeDepGraph(QTextStream &t)
+void DirDef::writeDepGraph(FTextStream &t)
 {
     writeDotDirDepGraph(t,this);
 }
@@ -673,7 +661,7 @@ static void writePartialDirPath(OutputList &ol,const DirDef *root,const DirDef *
   if (target->parent()!=root) 
   {
     writePartialDirPath(ol,root,target->parent());
-    ol.writeString("&nbsp;/&nbsp;");
+    ol.writeString("&#160;/&#160;");
   }
   ol.writeObjectLink(target->getReference(),target->getOutputFileBase(),0,target->shortName());
 }
@@ -683,7 +671,7 @@ static void writePartialFilePath(OutputList &ol,const DirDef *root,const FileDef
   if (fd->getDirDef() && fd->getDirDef()!=root)
   {
     writePartialDirPath(ol,root,fd->getDirDef());
-    ol.writeString("&nbsp;/&nbsp;");
+    ol.writeString("&#160;/&#160;");
   }
   if (fd->isLinkable())
   {
@@ -699,6 +687,7 @@ static void writePartialFilePath(OutputList &ol,const DirDef *root,const FileDef
 
 void DirRelation::writeDocumentation(OutputList &ol)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
@@ -708,25 +697,25 @@ void DirRelation::writeDocumentation(OutputList &ol)
   QCString title=theTranslator->trDirRelation(
                  m_src->displayName()+" -> "+
                  m_dst->dir()->shortName());
-  startFile(ol,getOutputFileBase(),getOutputFileBase(),title);
+  startFile(ol,getOutputFileBase(),getOutputFileBase(),
+            title,HLI_None,!generateTreeView,m_src->getOutputFileBase());
 
-  // write navigation path
-  m_src->writeNavigationPath(ol);
+  if (!generateTreeView)
+  {
+    // write navigation path
+    m_src->writeNavigationPath(ol);
+    ol.endQuickIndices();
+  }
+  ol.startContents();
 
-  //startTitle(ol,getOutputFileBase());
-  //  ol.parseText(shortTitle);
-  //endTitle(ol,getOutputFileBase(),title);
   ol.writeString("<h3>"+shortTitle+"</h3>");
-  
   ol.writeString("<table class=\"dirtab\">");
   ol.writeString("<tr class=\"dirtab\">");
-  // TODO: translate me! "File in %s"
-  ol.writeString("<th class=\"dirtab\">File in ");
-  m_src->writePathFragment(ol);
+  ol.writeString("<th class=\"dirtab\">");
+  ol.parseText(theTranslator->trFileIn(m_src->pathFragment()));
   ol.writeString("</th>");
-  // TODO: translate me! "Includes file in %s"
-  ol.writeString("<th class=\"dirtab\">Includes file in ");
-  m_dst->dir()->writePathFragment(ol);
+  ol.writeString("<th class=\"dirtab\">");
+  ol.parseText(theTranslator->trIncludesFileIn(m_dst->dir()->pathFragment()));
   ol.writeString("</th>");
   ol.writeString("</tr>");
 
@@ -744,8 +733,15 @@ void DirRelation::writeDocumentation(OutputList &ol)
     ol.writeString("</tr>");
   }
   ol.writeString("</table>");
+
+  ol.endContents();
   
-  endFile(ol); 
+  if (generateTreeView)
+  {
+    m_src->writeNavigationPath(ol);
+  }
+
+  endFile(ol,TRUE); 
   ol.popGeneratorState();
 }
 
