@@ -589,11 +589,11 @@ void GroupDef::writeGroupGraph(OutputList &ol)
       msg("Generating dependency graph for group %s\n",qualifiedName().data());
       ol.pushGeneratorState();
       ol.disable(OutputGenerator::Man);
-      ol.startParagraph();
+      //ol.startParagraph();
       ol.startGroupCollaboration();
       ol.parseText(theTranslator->trCollaborationDiagram(title));
       ol.endGroupCollaboration(graph);
-      ol.endParagraph();
+      //ol.endParagraph();
       ol.popGeneratorState();
     }
   }
@@ -604,7 +604,7 @@ void GroupDef::writeFiles(OutputList &ol,const QCString &title)
   // write list of files
   if (fileList->count()>0)
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader("files");
     ol.parseText(title);
     ol.endMemberHeader();
     ol.startMemberList();
@@ -645,7 +645,7 @@ void GroupDef::writeNestedGroups(OutputList &ol,const QCString &title)
   // write list of groups
   if (groupList->count()>0)
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader("groups");
     ol.parseText(title);
     ol.endMemberHeader();
     ol.startMemberList();
@@ -681,7 +681,7 @@ void GroupDef::writeDirs(OutputList &ol,const QCString &title)
   // write list of directories
   if (dirList->count()>0)
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader("dirs");
     ol.parseText(title);
     ol.endMemberHeader();
     ol.startMemberList();
@@ -753,6 +753,7 @@ void GroupDef::writeMemberGroups(OutputList &ol)
   /* write user defined member groups */
   if (memberGroupSDict)
   {
+    memberGroupSDict->sort();
     /* write user defined member groups */
     MemberGroupSDict::Iterator mgli(*memberGroupSDict);
     MemberGroup *mg;
@@ -803,14 +804,65 @@ void GroupDef::writeAuthorSection(OutputList &ol)
   ol.popGeneratorState();
 }
 
-void GroupDef::writeDocumentation(OutputList &ol)
+void GroupDef::writeSummaryLinks(OutputList &ol)
 {
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  QListIterator<LayoutDocEntry> eli(
+      LayoutDocManager::instance().docEntries(LayoutDocManager::Group));
+  LayoutDocEntry *lde;
+  bool first=TRUE;
+  for (eli.toFirst();(lde=eli.current());++eli)
+  {
+    if ((lde->kind()==LayoutDocEntry::GroupClasses && classSDict->declVisible()) || 
+        (lde->kind()==LayoutDocEntry::GroupNamespaces && namespaceSDict->declVisible()) ||
+        (lde->kind()==LayoutDocEntry::GroupFiles && fileList->count()>0) ||
+        (lde->kind()==LayoutDocEntry::GroupNestedGroups && groupList->count()>0) ||
+        (lde->kind()==LayoutDocEntry::GroupDirs && dirList->count()>0)
+       )
+    {
+      LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+      QCString label = lde->kind()==LayoutDocEntry::GroupClasses      ? "nested-classes" : 
+                       lde->kind()==LayoutDocEntry::GroupNamespaces   ? "namespaces"     :
+                       lde->kind()==LayoutDocEntry::GroupFiles        ? "files"          :
+                       lde->kind()==LayoutDocEntry::GroupNestedGroups ? "groups"         :
+                       "dirs";
+      writeSummaryLink(ol,label,ls->title,first);
+    }
+    else if (lde->kind()==LayoutDocEntry::MemberDecl)
+    {
+      LayoutDocEntryMemberDecl *lmd = (LayoutDocEntryMemberDecl*)lde;
+      MemberList * ml = getMemberList(lmd->type);
+      if (ml && ml->declVisible())
+      {
+        writeSummaryLink(ol,ml->listTypeAsString(),lmd->title,first);
+      }
+    }
+  }
+  if (!first)
+  {
+    ol.writeString("  </div>\n");
+  }
+  ol.popGeneratorState();
+}
+
+void GroupDef::writeDocumentation(OutputList &ol)
+{
+  //static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   ol.pushGeneratorState();
   startFile(ol,getOutputFileBase(),name(),title);
-  startTitle(ol,getOutputFileBase());
+
+  ol.startHeaderSection();
+  writeSummaryLinks(ol);
+  ol.startTitleHead(getOutputFileBase());
+  ol.pushGeneratorState();
+  ol.disable(OutputGenerator::Man);
   ol.parseText(title);
+  ol.popGeneratorState();
+  ol.endTitleHead(getOutputFileBase(),title);
   addGroupListToTitle(ol,this);
-  endTitle(ol,getOutputFileBase(),title);
+  ol.endHeaderSection();
+  ol.startContents();
 
   if (Doxygen::searchIndex)
   {
@@ -824,7 +876,7 @@ void GroupDef::writeDocumentation(OutputList &ol)
     }
   }
 
-  Doxygen::indexList.addIndexItem(this,0,0,title);
+  Doxygen::indexList.addIndexItem(this,0,title);
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
   {
@@ -945,6 +997,7 @@ void GroupDef::writeDocumentation(OutputList &ol)
   //---------------------------------------- end flexible part -------------------------------
 
   endFile(ol); 
+
   ol.popGeneratorState();
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
@@ -1116,7 +1169,7 @@ void addMemberToGroups(Entry *root,MemberDef *md)
       if (fgd && gd!=fgd && g->pri==pri) 
       {
          warn(root->fileName.data(), root->startLine,
-           "Warning: Member %s found in multiple %s groups! "
+           "warning: Member %s found in multiple %s groups! "
            "The member will be put in group %s, and not in group %s",
 	   md->name().data(), Grouping::getGroupPriName( pri ),
 	   gd->name().data(), fgd->name().data()
@@ -1161,7 +1214,7 @@ void addMemberToGroups(Entry *root,MemberDef *md)
           else if (!root->doc.isEmpty() && md->getGroupHasDocs())
           {
             warn(md->getGroupFileName(),md->getGroupStartLine(),
-                "Warning: Member documentation for %s found several times in %s groups!\n"
+                "warning: Member documentation for %s found several times in %s groups!\n"
                 "%s:%d: The member will remain in group %s, and won't be put into group %s",
                 md->name().data(), Grouping::getGroupPriName( pri ),
                 root->fileName.data(), root->startLine,
@@ -1277,14 +1330,30 @@ void GroupDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
   static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   static bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
   MemberList *ml = createMemberList(lt);
-  if (((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
-      ((ml->listType()&MemberList::documentationLists) && sortMemberDocs)
-     )
+  ml->setNeedsSorting(
+      ((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
+      ((ml->listType()&MemberList::documentationLists) && sortMemberDocs));
+  ml->append(md);
+
+#if 0  
+  if (ml->needsSorting())
     ml->inSort(md);
   else
     ml->append(md);
+#endif
 }
 
+void GroupDef::sortMemberLists()
+{
+  MemberList *ml = m_memberLists.first();
+  while (ml)
+  {
+    if (ml->needsSorting()) { ml->sort(); ml->setNeedsSorting(FALSE); }
+    ml = m_memberLists.next();
+  }
+}
+
+
 MemberList *GroupDef::getMemberList(MemberList::ListType lt) const
 {
   GroupDef *that = (GroupDef*)this;
