@@ -89,6 +89,11 @@ static bool mustBeOutsideParagraph(DocNode *n)
         case DocNode::Kind_SecRefList:
           /* <hr> */
         case DocNode::Kind_HorRuler:
+          /* CopyDoc gets paragraph markers from the wrapping DocPara node,
+           * but needs to insert them for all documentation being copied to
+           * preserve formatting.
+           */
+        case DocNode::Kind_Copy:
           return TRUE;
         case DocNode::Kind_StyleChange:
           return ((DocStyleChange*)n)->style()==DocStyleChange::Preformatted ||
@@ -124,7 +129,7 @@ static QString htmlAttribsToString(const HtmlAttribList &attribs)
 
 //-------------------------------------------------------------------------
 
-HtmlDocVisitor::HtmlDocVisitor(QTextStream &t,CodeOutputInterface &ci,
+HtmlDocVisitor::HtmlDocVisitor(FTextStream &t,CodeOutputInterface &ci,
                                const char *langExt) 
   : DocVisitor(DocVisitor_Html), m_t(t), m_ci(ci), m_insidePre(FALSE), 
                                  m_hide(FALSE), m_langExt(langExt)
@@ -174,6 +179,7 @@ void HtmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Amp:     m_t << "&amp;"; break;
     case DocSymbol::Dollar:  m_t << "$"; break;
     case DocSymbol::Hash:    m_t << "#"; break;
+    case DocSymbol::DoubleColon: m_t << "::"; break;
     case DocSymbol::Percent: m_t << "%"; break;
     case DocSymbol::Copy:    m_t << "&copy;"; break;
     case DocSymbol::Tm:      m_t << "&trade;"; break;
@@ -195,11 +201,11 @@ void HtmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Szlig:   m_t << "&szlig;"; break;
     case DocSymbol::Cedil:   m_t << "&" << s->letter() << "cedil;"; break;
     case DocSymbol::Ring:    m_t << "&" << s->letter() << "ring;"; break;
-    case DocSymbol::Nbsp:    m_t << "&nbsp;"; break;
+    case DocSymbol::Nbsp:    m_t << "&#160;"; break;
     case DocSymbol::AElig:   m_t << "&AElig;"; break;
     case DocSymbol::Aelig:   m_t << "&aelig;"; break;
     default:
-                             err("Error: unknown symbol found\n");
+                             err("error: unknown symbol found\n");
   }
 }
 
@@ -299,11 +305,11 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
   if (m_hide) return;
   switch(s->type())
   {
-    case DocVerbatim::Code: // fall though
+    case DocVerbatim::Code: 
       forceEndParagraph(s);
       m_t << PREFRAG_START;
       Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,s->context(),s->text().latin1(),
+                            ->parseCode(m_ci,s->context(),s->text(),
                                         s->isExample(),s->exampleFile());
       m_t << PREFRAG_END;
       forceStartParagraph(s);
@@ -400,7 +406,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
       Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,                 
                                         inc->context(),
-                                        inc->text().latin1(),
+                                        inc->text(),
                                         inc->isExample(),
                                         inc->exampleFile(),
                                         0,   // fd
@@ -420,7 +426,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,
                                            inc->context(),
-                                           inc->text().latin1(),
+                                           inc->text(),
                                            inc->isExample(),
                                            inc->exampleFile(), &fd);
          m_t << PREFRAG_END;
@@ -459,7 +465,7 @@ void HtmlDocVisitor::visit(DocIncOperator *op)
     {
       Doxygen::parserManager->getParser(m_langExt)
                             ->parseCode(m_ci,op->context(),
-                                op->text().latin1(),op->isExample(),
+                                op->text(),op->isExample(),
                                 op->exampleFile());
     }
     pushEnabled();
@@ -485,14 +491,36 @@ void HtmlDocVisitor::visit(DocFormula *f)
     forceEndParagraph(f);
     m_t << "<p class=\"formulaDsp\">" << endl;
   }
-  m_t << "<img class=\"formula" 
+
+  if (Config_getBool("USE_MATHJAX"))
+  {
+    QCString text = f->text();
+    bool closeInline = FALSE;
+    if (!bDisplay && !text.isEmpty() && text.at(0)=='$' && 
+                      text.at(text.length()-1)=='$')
+    {
+      closeInline=TRUE;
+      text = text.mid(1,text.length()-2);
+      m_t << "\\(";
+    }
+    m_t << convertToHtml(text);
+    if (closeInline)
+    {
+      m_t << "\\)";
+    }
+  }
+  else
+  {
+    m_t << "<img class=\"formula" 
       << (bDisplay ? "Dsp" : "Inl");
-  m_t << "\" alt=\"";
-  filterQuotedCdataAttr(f->text());
-  m_t << "\"";
-  /// @todo cache image dimensions on formula generation and give height/width
-  /// for faster preloading and better rendering of the page
-  m_t << " src=\"" << f->relPath() << f->name() << ".png\"/>";
+    m_t << "\" alt=\"";
+    filterQuotedCdataAttr(f->text());
+    m_t << "\"";
+    /// @todo cache image dimensions on formula generation and give height/width
+    /// for faster preloading and better rendering of the page
+    m_t << " src=\"" << f->relPath() << f->name() << ".png\"/>";
+
+  }
   if (bDisplay)
   {
     m_t << endl << "</p>" << endl;
@@ -513,7 +541,7 @@ void HtmlDocVisitor::visit(DocIndexEntry *e)
   //       e->scope()  ? e->scope()->name().data()  : "<null>",
   //       e->member() ? e->member()->name().data() : "<null>"
   //      );
-  Doxygen::indexList.addIndexItem(e->scope(),e->member(),anchor,e->entry());
+  Doxygen::indexList.addIndexItem(e->scope(),e->member(),e->entry());
 }
 
 void HtmlDocVisitor::visit(DocSimpleSectSep *)
@@ -633,14 +661,12 @@ static int getParagraphContext(DocPara *p,bool &isFirst,bool &isLast)
       case DocNode::Kind_AutoListItem:
         isFirst=TRUE;
         isLast =TRUE;
-        if (isFirst) t=1;
-        if (isLast)  t=3;
+        t=1; // not used
         break;
       case DocNode::Kind_SimpleListItem:
         isFirst=TRUE;
         isLast =TRUE;
-        if (isFirst) t=1;
-        if (isLast)  t=3;
+        t=1; // not used
         break;
       case DocNode::Kind_HtmlListItem:
         isFirst=isFirstChildNode((DocHtmlListItem*)p->parent(),p);
@@ -715,6 +741,7 @@ void HtmlDocVisitor::visitPre(DocPara *p)
       case DocNode::Kind_AutoListItem:
       case DocNode::Kind_SimpleSect:
       case DocNode::Kind_XRefItem:
+      case DocNode::Kind_Copy:
         needsTag = TRUE;
         break;
       case DocNode::Kind_Root:
@@ -795,6 +822,7 @@ void HtmlDocVisitor::visitPost(DocPara *p)
       case DocNode::Kind_AutoListItem:
       case DocNode::Kind_SimpleSect:
       case DocNode::Kind_XRefItem:
+      case DocNode::Kind_Copy:
         needsTag = TRUE;
         break;
       case DocNode::Kind_Root:
@@ -944,9 +972,9 @@ void HtmlDocVisitor::visitPre(DocSection *s)
   forceEndParagraph(s);
   m_t << "<h" << s->level()+1 << ">";
   m_t << "<a class=\"anchor\" id=\"" << s->anchor();
-  m_t << "\">" << endl;
+  m_t << "\"></a>" << endl;
   filter(convertCharEntitiesToUTF8(s->title().data()));
-  m_t << "</a></h" << s->level()+1 << ">\n";
+  m_t << "</h" << s->level()+1 << ">\n";
 }
 
 void HtmlDocVisitor::visitPost(DocSection *s) 
@@ -1165,7 +1193,8 @@ void HtmlDocVisitor::visitPre(DocImage *img)
     }
     m_t << "<div align=\"center\">" << endl;
     m_t << "<img src=\"" << img->relPath() << img->name() << "\" alt=\"" 
-      << baseName << "\"" << "/>" << endl;
+        << baseName << "\"" << htmlAttribsToString(img->attribs()) 
+        << "/>" << endl;
     if (img->hasCaption())
     {
       m_t << "<p><strong>";
@@ -1217,6 +1246,26 @@ void HtmlDocVisitor::visitPost(DocDotFile *df)
   m_t << "</div>" << endl;
 }
 
+void HtmlDocVisitor::visitPre(DocMscFile *df)
+{
+  if (m_hide) return;
+  writeMscFile(df->file(),df->relPath(),df->context());
+  m_t << "<div align=\"center\">" << endl;
+  if (df->hasCaption())
+  { 
+    m_t << "<p><strong>";
+  }
+}
+void HtmlDocVisitor::visitPost(DocMscFile *df) 
+{
+  if (m_hide) return;
+  if (df->hasCaption())
+  {
+    m_t << "</strong></p>" << endl;
+  }
+  m_t << "</div>" << endl;
+}
+
 void HtmlDocVisitor::visitPre(DocLink *lnk)
 {
   if (m_hide) return;
@@ -1305,25 +1354,33 @@ void HtmlDocVisitor::visitPre(DocParamSect *s)
   if (m_hide) return;
   forceEndParagraph(s);
   m_t << "<dl><dt><b>";
+  QCString className;
   switch(s->type())
   {
     case DocParamSect::Param: 
-      m_t << theTranslator->trParameters(); break;
+      m_t << theTranslator->trParameters(); 
+      className="params";
+      break;
     case DocParamSect::RetVal: 
-      m_t << theTranslator->trReturnValues(); break;
+      m_t << theTranslator->trReturnValues(); 
+      className="retval";
+      break;
     case DocParamSect::Exception: 
-      m_t << theTranslator->trExceptions(); break;
+      m_t << theTranslator->trExceptions(); 
+      className="exception";
+      break;
     case DocParamSect::TemplateParam: 
       /* TODO: add this 
       m_t << theTranslator->trTemplateParam(); break;
       */
       m_t << "Template Parameters"; break;
+      className="tparams";
     default:
       ASSERT(0);
   }
   m_t << ":";
   m_t << "</b></dt><dd>" << endl;
-  m_t << "  <table border=\"0\" cellspacing=\"2\" cellpadding=\"0\">" << endl;
+  m_t << "  <table class=\"" << className << "\">" << endl;
 }
 
 void HtmlDocVisitor::visitPost(DocParamSect *s)
@@ -1338,25 +1395,55 @@ void HtmlDocVisitor::visitPost(DocParamSect *s)
 void HtmlDocVisitor::visitPre(DocParamList *pl)
 {
   if (m_hide) return;
-  m_t << "    <tr><td valign=\"top\">";
-  if (pl->direction()!=DocParamSect::Unspecified)
+  m_t << "    <tr>";
+  DocParamSect *sect = 0;
+  if (pl->parent()->kind()==DocNode::Kind_ParamSect)
   {
-    m_t << "<tt>[";
-    if (pl->direction()==DocParamSect::In)
-    {
-      m_t << "in";
-    }
-    else if (pl->direction()==DocParamSect::Out)
-    {
-      m_t << "out";
-    }
-    else if (pl->direction()==DocParamSect::InOut)
-    {
-      m_t << "in,out";
-    }
-    m_t << "]</tt>&nbsp;";
+    sect=(DocParamSect*)pl->parent();
   }
-  m_t << "</td><td valign=\"top\"><em>";
+  if (sect && sect->hasInOutSpecifier())
+  {
+    m_t << "<td class=\"paramdir\">";
+    if (pl->direction()!=DocParamSect::Unspecified)
+    {
+      m_t << "[";
+      if (pl->direction()==DocParamSect::In)
+      {
+        m_t << "in";
+      }
+      else if (pl->direction()==DocParamSect::Out)
+      {
+        m_t << "out";
+      }
+      else if (pl->direction()==DocParamSect::InOut)
+      {
+        m_t << "in,out";
+      }
+      m_t << "]";
+    }
+    m_t << "</td>";
+  }
+  if (sect && sect->hasTypeSpecifier())
+  {
+    m_t << "<td class=\"paramtype\">";
+    QListIterator<DocNode> li(pl->paramTypes());
+    DocNode *type;
+    bool first=TRUE;
+    for (li.toFirst();(type=li.current());++li)
+    {
+      if (!first) m_t << "&#160;|&#160;"; else first=FALSE;
+      if (type->kind()==DocNode::Kind_Word)
+      {
+        visit((DocWord*)type); 
+      }
+      else if (type->kind()==DocNode::Kind_LinkedWord)
+      {
+        visit((DocLinkedWord*)type); 
+      }
+    }
+    m_t << "</td>";
+  }
+  m_t << "<td class=\"paramname\">";
   //QStrListIterator li(pl->parameters());
   //const char *s;
   QListIterator<DocNode> li(pl->parameters());
@@ -1374,7 +1461,7 @@ void HtmlDocVisitor::visitPre(DocParamList *pl)
       visit((DocLinkedWord*)param); 
     }
   }
-  m_t << "</em>&nbsp;</td><td>";
+  m_t << "</td><td>";
 }
 
 void HtmlDocVisitor::visitPost(DocParamList *)
@@ -1495,31 +1582,21 @@ void HtmlDocVisitor::filterQuotedCdataAttr(const char* str)
   }
 }
 
-void HtmlDocVisitor::startLink(const QString &ref,const QString &file,
-                               const QString &relPath,const QString &anchor,
-                               const QString &tooltip)
+void HtmlDocVisitor::startLink(const QCString &ref,const QCString &file,
+                               const QCString &relPath,const QCString &anchor,
+                               const QCString &tooltip)
 {
-  QCString *dest;
   if (!ref.isEmpty()) // link to entity imported via tag file
   {
     m_t << "<a class=\"elRef\" ";
-    m_t << "doxygen=\"" << ref << ":";
-    if ((dest=Doxygen::tagDestinationDict[ref])) m_t << *dest << "/";
-    m_t << "\" ";
+    m_t << externalLinkTarget() << externalRef(relPath,ref,FALSE);
   }
   else // local link
   {
     m_t << "<a class=\"el\" ";
   }
   m_t << "href=\"";
-  if (!ref.isEmpty())
-  {
-    if ((dest=Doxygen::tagDestinationDict[ref])) m_t << *dest << "/";
-  }
-  else
-  {
-    m_t << relPath;
-  }
+  m_t << externalRef(relPath,ref,TRUE);
   if (!file.isEmpty()) m_t << file << Doxygen::htmlFileExtension;
   if (!anchor.isEmpty()) m_t << "#" << anchor;
   m_t << "\"";
@@ -1545,42 +1622,45 @@ void HtmlDocVisitor::popEnabled()
   delete v;
 }
 
-void HtmlDocVisitor::writeDotFile(const QString &fileName,const QString &relPath,
-                                  const QString &context)
+void HtmlDocVisitor::writeDotFile(const QCString &fn,const QCString &relPath,
+                                  const QCString &context)
 {
-  QString baseName=fileName;
+  QCString baseName=fn;
   int i;
   if ((i=baseName.findRev('/'))!=-1)
   {
     baseName=baseName.right(baseName.length()-i-1);
   }
-  QString outDir = Config_getString("HTML_OUTPUT");
-  writeDotGraphFromFile(fileName,outDir,baseName,BITMAP);
-  QString mapName = baseName+".map";
-  QString mapFile = fileName+".map";
-  m_t << "<img src=\"" << relPath << baseName << "." 
-    << Config_getEnum("DOT_IMAGE_FORMAT") << "\" alt=\""
-    << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
-  QString imap = getDotImageMapFromFile(baseName,outDir,relPath.data(),context);
-  m_t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" << imap << "</map>" << endl;
+  QCString outDir = Config_getString("HTML_OUTPUT");
+  writeDotGraphFromFile(fn,outDir,baseName,BITMAP);
+  QCString mapName = baseName+".map";
+  QCString mapFile = fn+".map";
+  //m_t << "<img src=\"" << relPath << baseName << "." 
+  //    << Config_getEnum("DOT_IMAGE_FORMAT") << "\" alt=\""
+  //    << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" 
+  //    << endl;
+  //QCString imap = getDotImageMapFromFile(m_t,fn,baseName,outDir,relPath,context);
+  //m_t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" 
+  //    << imap << "</map>" << endl;
+  writeDotImageMapFromFile(m_t,fn,outDir,relPath,context);
 }
 
-void HtmlDocVisitor::writeMscFile(const QString &fileName,const QString &relPath,
-                                  const QString &context)
+void HtmlDocVisitor::writeMscFile(const QCString &fileName,const QCString &relPath,
+                                  const QCString &context)
 {
-  QString baseName=fileName;
+  QCString baseName=fileName;
   int i;
   if ((i=baseName.findRev('/'))!=-1)
   {
     baseName=baseName.right(baseName.length()-i-1);
   }
-  QString outDir = Config_getString("HTML_OUTPUT");
+  QCString outDir = Config_getString("HTML_OUTPUT");
   writeMscGraphFromFile(fileName,outDir,baseName,MSC_BITMAP);
-  QString mapName = baseName+".map";
-  QString mapFile = fileName+".map";
+  QCString mapName = baseName+".map";
+  QCString mapFile = fileName+".map";
   m_t << "<img src=\"" << relPath << baseName << ".png\" alt=\""
     << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
-  QString imap = getMscImageMapFromFile(fileName,outDir,relPath.data(),context);
+  QCString imap = getMscImageMapFromFile(fileName,outDir,relPath,context);
   m_t << "<map name=\"" << mapName << "\" id=\"" << mapName << "\">" << imap << "</map>" << endl;
 }
 
