@@ -92,7 +92,7 @@ void LatexGenerator::init()
   QCString latex_command = Config_getString("LATEX_CMD_NAME");
   QCString mkidx_command = Config_getString("MAKEINDEX_CMD_NAME");
   // end insertion by KONNO Akihisa <konno@researchers.jp> 2002-03-05
-  QTextStream t(&file);
+  FTextStream t(&file);
   if (!Config_getBool("USE_PDFLATEX")) // use plain old latex
   {
     t << "all: clean refman.dvi" << endl
@@ -161,12 +161,13 @@ void LatexGenerator::init()
 
   t << endl
     << "clean:" << endl
-    << "\trm -f *.ps *.dvi *.aux *.toc *.idx *.ind *.ilg *.log *.out refman.pdf" << endl;
+    << "\trm -f " 
+    << "*.ps *.dvi *.aux *.toc *.idx *.ind *.ilg *.log *.out refman.pdf" << endl;
 
   createSubDirs(d);
 }
 
-static void writeDefaultHeaderPart1(QTextStream &t)
+static void writeDefaultHeaderPart1(FTextStream &t)
 {
   // part 1
 
@@ -182,21 +183,24 @@ static void writeDefaultHeaderPart1(QTextStream &t)
   t << "]{";
   if (Config_getBool("COMPACT_LATEX")) t << "article"; else t << "book";
   t << "}\n";
-  if (paperType=="a4wide") t << "\\usepackage{a4wide}\n";
+  // the next package is obsolete (see bug 563698)
+  //if (paperType=="a4wide") t << "\\usepackage{a4wide}\n";
   t << "\\usepackage{makeidx}\n"
     "\\usepackage{graphicx}\n"
     "\\usepackage{multicol}\n"
     "\\usepackage{float}\n"
     "\\usepackage{listings}\n"
     "\\usepackage{color}\n"
+    "\\usepackage{ifthen}\n"
+    "\\usepackage[table]{xcolor}\n"
     "\\usepackage{textcomp}\n"
     "\\usepackage{alltt}\n"
     //"\\usepackage{ae,aecompl,aeguill}\n"
     ;
-  if (Config_getBool("USE_PDFLATEX"))
-  {
-    t << "\\usepackage{times}" << endl;
-  }
+  //if (Config_getBool("USE_PDFLATEX"))
+  //{
+  //  t << "\\usepackage{times}" << endl;
+  //}
   if (Config_getBool("PDF_HYPERLINKS")) 
   {
     t << "\\usepackage{ifpdf}" << endl
@@ -229,6 +233,9 @@ static void writeDefaultHeaderPart1(QTextStream &t)
     // if the command is empty, no output is needed.
     t << sLanguageSupportCommand << endl;
   }
+  t << "\\usepackage{mathptmx}\n";
+  t << "\\usepackage[scaled=.90]{helvet}\n";
+  t << "\\usepackage{courier}\n";
   t << "\\usepackage{doxygen}\n";
 
   // define option for listings
@@ -267,7 +274,7 @@ static void writeDefaultHeaderPart1(QTextStream &t)
 
 }
 
-static void writeDefaultHeaderPart2(QTextStream &t)
+static void writeDefaultHeaderPart2(FTextStream &t)
 {
   // part 2
   t << "}\\\\" << endl
@@ -275,7 +282,7 @@ static void writeDefaultHeaderPart2(QTextStream &t)
     << "{\\large ";
 }
 
-static void writeDefaultHeaderPart3(QTextStream &t)
+static void writeDefaultHeaderPart3(FTextStream &t)
 {
   // part 3
   t << " Doxygen " << versionString << "}\\\\" << endl
@@ -296,7 +303,7 @@ static void writeDefaultHeaderPart3(QTextStream &t)
   }
 }
 
-static void writeDefaultStyleSheetPart1(QTextStream &t)
+static void writeDefaultStyleSheetPart1(FTextStream &t)
 {
   // part 1
   t << "\\NeedsTeXFormat{LaTeX2e}\n"
@@ -307,7 +314,53 @@ static void writeDefaultStyleSheetPart1(QTextStream &t)
        "\\RequirePackage{calc}\n"
        "\\RequirePackage{color}\n"
        "\\RequirePackage{fancyhdr}\n"
-       "\\RequirePackage{verbatim}\n\n";
+       "\\RequirePackage{longtable}\n"
+       "\\RequirePackage{verbatim}\n"
+       "\\RequirePackage{ifthen}\n"
+       "\\RequirePackage{xcolor}\n\n";
+
+  t << "% Use helvetica font instead of times roman\n"
+       "\\RequirePackage{helvet}\n"
+       "\\RequirePackage{sectsty}\n"
+       "\\RequirePackage{tocloft}\n"
+       "\\allsectionsfont{\\usefont{OT1}{phv}{bc}{n}\\selectfont}\n"
+       "\\providecommand{\\cftchapfont}{%\n"
+       "  \\fontsize{11}{13}\\usefont{OT1}{phv}{bc}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cftchappagefont}{%\n"
+       "  \\fontsize{11}{13}\\usefont{OT1}{phv}{c}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cftsecfont}{%\n"
+       "  \\fontsize{10}{12}\\usefont{OT1}{phv}{c}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cftsecpagefont}{%\n"
+       "  \\fontsize{10}{12}\\usefont{OT1}{phv}{c}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cftsubsecfont}{%\n"
+       "  \\fontsize{10}{12}\\usefont{OT1}{phv}{c}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cftsubsecpagefont}{%\n"
+       "  \\fontsize{10}{12}\\usefont{OT1}{phv}{c}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cftsubsubsecfont}{%\n"
+       "  \\fontsize{9}{11}\\usefont{OT1}{phv}{c}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cftsubsubsecpagefont}{%\n"
+       "  \\fontsize{9}{11}\\usefont{OT1}{phv}{c}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cftparafont}{%\n"
+       "  \\fontsize{9}{11}\\usefont{OT1}{phv}{c}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cftparapagefont}{%\n"
+       "  \\fontsize{9}{11}\\usefont{OT1}{phv}{c}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\cfttoctitlefont}{%\n"
+       "  \\fontsize{20}{22}\\usefont{OT1}{phv}{b}{n}\\selectfont\n"
+       "}\n"
+       "\\providecommand{\\rmdefault}{phv}\n"
+       "\\providecommand{\\bfdefault}{bc}\n"
+       "\n\n";
+
   t << "% Setup fancy headings\n"
        "\\pagestyle{fancyplain}\n"
        "\\newcommand{\\clearemptydoublepage}{%\n"
@@ -320,24 +373,42 @@ static void writeDefaultStyleSheetPart1(QTextStream &t)
   t << "\\renewcommand{\\sectionmark}[1]{%\n"
        "  \\markright{\\thesection\\ #1}%\n"
        "}\n";
-  t << "\\lhead[\\fancyplain{}{\\bfseries\\thepage}]{%\n"
-       "  \\fancyplain{}{\\bfseries\\rightmark}%\n"
-       "}\n";
-  t << "\\rhead[\\fancyplain{}{\\bfseries\\leftmark}]{%\n"
-       "  \\fancyplain{}{\\bfseries\\thepage}%\n"
-       "}\n";
-  t << "\\rfoot[\\fancyplain{}{\\bfseries\\scriptsize%\n  ";
+
+  //t << "\\lhead[\\fancyplain{}{\\bfseries\\thepage}]{%\n"
+  //     "  \\fancyplain{}{\\bfseries\\rightmark}%\n"
+  //     "}\n";
+  //t << "\\rhead[\\fancyplain{}{\\bfseries\\leftmark}]{%\n"
+  //     "  \\fancyplain{}{\\bfseries\\thepage}%\n"
+  //     "}\n";
+  //t << "\\rfoot[\\fancyplain{}{\\bfseries\\scriptsize%\n  ";
+  t << "\\fancyhead[LE]{\\fancyplain{}{\\bfseries\\thepage}}\n";
+  t << "\\fancyhead[CE]{\\fancyplain{}{}}\n";
+  t << "\\fancyhead[RE]{\\fancyplain{}{\\bfseries\\leftmark}}\n";
+  t << "\\fancyhead[LO]{\\fancyplain{}{\\bfseries\\rightmark}}\n";
+  t << "\\fancyhead[CO]{\\fancyplain{}{}}\n";
+  t << "\\fancyhead[RO]{\\fancyplain{}{\\bfseries\\thepage}}\n";
+
+  t << "\\fancyfoot[LE]{\\fancyplain{}{}}\n";
+  t << "\\fancyfoot[CE]{\\fancyplain{}{}}\n";
+  t << "\\fancyfoot[RE]{\\fancyplain{}{\\bfseries\\scriptsize ";
 }
 
-static void writeDefaultStyleSheetPart2(QTextStream &t)
-{
-  t << "\\lfoot[]{\\fancyplain{}{\\bfseries\\scriptsize%\n  ";
-}
-
-static void writeDefaultStyleSheetPart3(QTextStream &t)
+static void writeDefaultStyleSheetPart2(FTextStream &t)
 {
   t << "}}\n";
-  t << "\\cfoot{}\n\n";
+  t << "\\fancyfoot[LO]{\\fancyplain{}{\\bfseries\\scriptsize ";
+  //t << "\\lfoot[]{\\fancyplain{}{\\bfseries\\scriptsize%\n  ";
+
+}
+
+static void writeDefaultStyleSheetPart3(FTextStream &t)
+{
+  static bool latexSourceCode = Config_getBool("LATEX_SOURCE_CODE");
+  t << "}}\n";
+  //t << "\\cfoot{}\n\n";
+  t << "\\fancyfoot[CO]{\\fancyplain{}{}}\n";
+  t << "\\fancyfoot[RO]{\\fancyplain{}{}}\n";
+
   t << "%---------- Internal commands used in this style file ----------------\n\n";
   t << "% Generic environment used by all paragraph-based environments defined\n"
        "% below. Note that the command \\title{...} needs to be defined inside\n"
@@ -365,13 +436,27 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
        "  \\normalsize%\n"
        "}\n\n";
   t << "% Used by @code ... @endcode\n"
-       "\\newenvironment{DoxyCode}{%\n"
-       "  \\footnotesize%\n"
-       "  \\verbatim%\n"
-       "}{%\n"
-       "  \\endverbatim%\n"
-       "  \\normalsize%\n"
-       "}\n\n";
+       "\\newenvironment{DoxyCode}{%\n";
+  if (latexSourceCode)
+  {
+    t << "\n\n\\begin{footnotesize}\\begin{alltt}%" << endl;
+  }
+  else
+  {
+    t << "  \\footnotesize%\n"
+         "  \\verbatim%\n";
+  }
+  t << "}{%\n";
+  if (latexSourceCode)
+  {
+    t << "\\end{alltt}\\end{footnotesize}%" << endl; 
+  }
+  else
+  {
+    t << "  \\endverbatim%\n"
+         "  \\normalsize%\n";
+  }
+  t << "}\n\n";
   t << "% Used by @example, @include, @includelineno and @dontinclude\n"
        "\\newenvironment{DoxyCodeInclude}{%\n"
        "  \\DoxyCode%\n"
@@ -522,18 +607,50 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
        "  \\end{list}%\n"
        "}\n\n";
   t << "% Used by parameter lists\n"
-       "\\newenvironment{DoxyParams}[1]{%\n"
-       "  \\begin{DoxyDesc}{#1}%\n"
+       "\\newenvironment{DoxyParams}[2][]{%\n"
+       "  \\begin{DoxyDesc}{#2}%\n"
        "    \\begin{description}%\n"
+       "      \\item[] \\hspace{\\fill} \\vspace{-25pt}%\n"
+       "      \\definecolor{tableShade}{HTML}{F8F8F8}%\n"
+       "      \\rowcolors{1}{white}{tableShade}%\n"
+       "      \\arrayrulecolor{gray}%\n"
+       "      \\setlength{\\tabcolsep}{0.01\\textwidth}%\n"
+       "      \\ifthenelse{\\equal{#1}{}}\n" // default: name, docs columns
+       "      {\\begin{longtable}{|>{\\raggedleft\\hspace{0pt}}p{0.15\\textwidth}|%\n"
+       "                          p{0.87\\textwidth}|}}%\n"
+       "      {\\ifthenelse{\\equal{#1}{1}}%\n" // inout, name, docs columns, or type, name, docs columns
+       "       {\\begin{longtable}{|>{\\centering}p{0.10\\textwidth}|%\n"
+       "                          >{\\raggedleft\\hspace{0pt}}p{0.15\\textwidth}|%\n"
+       "                          p{0.75\\textwidth}|}}%\n"
+       "       {\\begin{longtable}{|>{\\centering}p{0.10\\textwidth}|%\n" // inout, type, name, docs columns
+       "                          >{\\centering\\hspace{0pt}}p{0.15\\textwidth}|%\n"
+       "                          >{\\raggedleft\\hspace{0pt}}p{0.15\\textwidth}|%\n"
+       "                          p{0.58\\textwidth}|}}%\n"
+       "       }\\hline%\n"
        "}{%\n"
+       "      \\end{longtable}%\n"
        "    \\end{description}%\n"
        "  \\end{DoxyDesc}%\n"
        "}\n\n";
+  t << "% is used for parameters within a detailed function description\n"
+       "\\newenvironment{DoxyParamCaption}{%\n"
+       "  \\renewcommand{\\item}[2][]{##1 {\\em ##2}}%\n"
+       "  }{%\n"
+       "}\n\n";
   t << "% Used by return value lists\n"
        "\\newenvironment{DoxyRetVals}[1]{%\n"
        "  \\begin{DoxyDesc}{#1}%\n"
        "    \\begin{description}%\n"
+       "      \\item[] \\hspace{\\fill} \\vspace{-25pt}%\n"
+       "      \\definecolor{tableShade}{HTML}{F8F8F8}%\n"
+       "      \\rowcolors{1}{white}{tableShade}%\n"
+       "      \\arrayrulecolor{gray}%\n"
+       "      \\setlength{\\tabcolsep}{0.01\\textwidth}%\n"
+       "      \\begin{longtable}{|>{\\raggedleft\\hspace{0pt}}p{0.25\\textwidth}|%\n"
+       "                          p{0.77\\textwidth}|}%\n"
+       "      \\hline%\n"
        "}{%\n"
+       "      \\end{longtable}%\n"
        "    \\end{description}%\n"
        "  \\end{DoxyDesc}%\n"
        "}\n\n";
@@ -541,7 +658,16 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
        "\\newenvironment{DoxyExceptions}[1]{%\n"
        "  \\begin{DoxyDesc}{#1}%\n"
        "    \\begin{description}%\n"
+       "      \\item[] \\hspace{\\fill} \\vspace{-25pt}%\n"
+       "      \\definecolor{tableShade}{HTML}{F8F8F8}%\n"
+       "      \\rowcolors{1}{white}{tableShade}%\n"
+       "      \\arrayrulecolor{gray}%\n"
+       "      \\setlength{\\tabcolsep}{0.01\\textwidth}%\n"
+       "      \\begin{longtable}{|>{\\raggedleft\\hspace{0pt}}p{0.25\\textwidth}|%\n"
+       "                          p{0.77\\textwidth}|}%\n"
+       "      \\hline%\n"
        "}{%\n"
+       "      \\end{longtable}%\n"
        "    \\end{description}%\n"
        "  \\end{DoxyDesc}%\n"
        "}\n\n";
@@ -549,7 +675,16 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
        "\\newenvironment{DoxyTemplParams}[1]{%\n"
        "  \\begin{DoxyDesc}{#1}%\n"
        "    \\begin{description}%\n"
+       "      \\item[] \\hspace{\\fill} \\vspace{-25pt}%\n"
+       "      \\definecolor{tableShade}{HTML}{F8F8F8}%\n"
+       "      \\rowcolors{1}{white}{tableShade}%\n"
+       "      \\arrayrulecolor{gray}%\n"
+       "      \\setlength{\\tabcolsep}{0.01\\textwidth}%\n"
+       "      \\begin{longtable}{|>{\\raggedleft\\hspace{0pt}}p{0.25\\textwidth}|%\n"
+       "                          p{0.77\\textwidth}|}%\n"
+       "      \\hline%\n"
        "}{%\n"
+       "      \\end{longtable}%\n"
        "    \\end{description}%\n"
        "  \\end{DoxyDesc}%\n"
        "}\n\n";
@@ -603,7 +738,8 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
   t << "\\setlength{\\parindent}{0cm}\n";
   t << "\\setlength{\\parskip}{0.2cm}\n";
   t << "\\addtocounter{secnumdepth}{1}\n";
-  t << "\\sloppy\n";
+  // \sloppy should not be used, see bug 563698 
+  //t << "\\sloppy\n";
   t << "\\usepackage[T1]{fontenc}\n";
   t << "\\makeatletter\n";
   t << "\\renewcommand{\\paragraph}{\\@startsection{paragraph}{4}{0ex}%\n";
@@ -628,7 +764,7 @@ static void writeDefaultStyleSheetPart3(QTextStream &t)
 
 void LatexGenerator::writeHeaderFile(QFile &f)
 {
-  QTextStream t(&f);
+  FTextStream t(&f);
   writeDefaultHeaderPart1(t);
   t << "Your title here";
   writeDefaultHeaderPart2(t);
@@ -638,8 +774,7 @@ void LatexGenerator::writeHeaderFile(QFile &f)
 
 void LatexGenerator::writeStyleSheetFile(QFile &f)
 {
-  QTextStream t(&f);
-  t.setEncoding(QTextStream::UnicodeUTF8);
+  FTextStream t(&f);
 
   writeDefaultStyleSheetPart1(t);
   QCString &projectName = Config_getString("PROJECT_NAME");
@@ -855,7 +990,7 @@ void LatexGenerator::startIndexSection(IndexSections is)
 
 void LatexGenerator::endIndexSection(IndexSections is)
 {
-  static bool compactLatex = Config_getBool("COMPACT_LATEX");
+  //static bool compactLatex = Config_getBool("COMPACT_LATEX");
   static bool sourceBrowser = Config_getBool("SOURCE_BROWSER");
   static QCString latexHeader = Config_getString("LATEX_HEADER");
   switch (is)
@@ -914,7 +1049,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (!gd->isReference())
           {
-            if (compactLatex) t << "\\input"; else t << "\\include";
+            //if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "\\input"; 
             t << "{" << gd->getOutputFileBase() << "}\n";
           }
         }
@@ -937,7 +1073,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (dd->isLinkableInProject())
           {
-            if (compactLatex) t << "\\input"; else t << "\\include";
+            //if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "\\input"; 
             t << "{" << dd->getOutputFileBase() << "}\n";
           }
         }
@@ -960,7 +1097,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (nd->isLinkableInProject())
           {
-            if (compactLatex) t << "\\input"; else t << "\\include";
+            //if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "\\input"; 
             t << "{" << nd->getOutputFileBase() << "}\n";
           }
           ++nli;
@@ -984,7 +1122,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (cd->isLinkableInProject() && cd->templateMaster()==0)
           {
-            if (compactLatex) t << "\\input"; else t << "\\include";
+            //if (compactLatex) t << "\\input"; else t << "\\include";
+            t << "\\input"; 
             t << "{" << cd->getOutputFileBase() << "}\n";
           } 
         }
@@ -1006,17 +1145,20 @@ void LatexGenerator::endIndexSection(IndexSections is)
                 t << "}\n\\input{" << fd->getOutputFileBase() << "}\n";
                 if (sourceBrowser && m_prettyCode && fd->generateSourceFile())
                 {
-                  t << "\\include{" << fd->getSourceFileBase() << "}\n";
+                  //t << "\\include{" << fd->getSourceFileBase() << "}\n";
+                  t << "\\input{" << fd->getSourceFileBase() << "}\n";
                 }
                 isFirst=FALSE;
               }
               else
               {
-                if (compactLatex) t << "\\input" ; else t << "\\include";
+                //if (compactLatex) t << "\\input" ; else t << "\\include";
+                t << "\\input" ; 
                 t << "{" << fd->getOutputFileBase() << "}\n";
                 if (sourceBrowser && m_prettyCode && fd->generateSourceFile())
                 {
-                  t << "\\include{" << fd->getSourceFileBase() << "}\n";
+                  //t << "\\include{" << fd->getSourceFileBase() << "}\n";
+                  t << "\\input{" << fd->getSourceFileBase() << "}\n";
                 }
               }
             }
@@ -1037,7 +1179,8 @@ void LatexGenerator::endIndexSection(IndexSections is)
         }
         for (++pdi;(pd=pdi.current());++pdi)
         {
-          if (compactLatex) t << "\\input" ; else t << "\\include";
+          //if (compactLatex) t << "\\input" ; else t << "\\include";
+          t << "\\input"; 
           t << "{" << pd->getOutputFileBase() << "}\n";
         }
       }
@@ -1074,10 +1217,12 @@ void LatexGenerator::endIndexSection(IndexSections is)
   }
 }
 
-void LatexGenerator::writePageLink(const char *name, bool first)
+void LatexGenerator::writePageLink(const char *name, bool /*first*/)
 {
-  bool &compactLatex = Config_getBool("COMPACT_LATEX");
-  if (compactLatex || first) t << "\\input" ; else t << "\\include";
+  //bool &compactLatex = Config_getBool("COMPACT_LATEX");
+  // next is remove for bug615957
+  //if (compactLatex || first) t << "\\input" ; else t << "\\include";
+  t << "\\input" ; 
   t << "{" << name << "}\n";
 }
 
@@ -1099,14 +1244,11 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2010";
-        t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2010";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -1380,7 +1522,7 @@ void LatexGenerator::endGroupHeader()
   t << "}" << endl;
 }
 
-void LatexGenerator::startMemberHeader()
+void LatexGenerator::startMemberHeader(const char *)
 {
   if (Config_getBool("COMPACT_LATEX")) 
   {
@@ -1572,7 +1714,6 @@ void LatexGenerator::endSection(const char *lab,SectionInfo::SectionType)
 }
 
 
-//void LatexGenerator::docifyStatic(QTextStream &t,const char *str)
 void LatexGenerator::docify(const char *str)
 {
   filterLatexString(t,str,insideTabbing,FALSE);
@@ -1817,7 +1958,7 @@ void LatexGenerator::startDotGraph()
 
 void LatexGenerator::endDotGraph(const DotClassGraph &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startInclDepGraph() 
@@ -1826,7 +1967,7 @@ void LatexGenerator::startInclDepGraph()
 
 void LatexGenerator::endInclDepGraph(const DotInclDepGraph &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startGroupCollaboration() 
@@ -1835,7 +1976,7 @@ void LatexGenerator::startGroupCollaboration()
 
 void LatexGenerator::endGroupCollaboration(const DotGroupCollaboration &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startCallGraph() 
@@ -1844,7 +1985,7 @@ void LatexGenerator::startCallGraph()
 
 void LatexGenerator::endCallGraph(const DotCallGraph &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startDirDepGraph() 
@@ -1853,7 +1994,7 @@ void LatexGenerator::startDirDepGraph()
 
 void LatexGenerator::endDirDepGraph(const DotDirDeps &g) 
 {
-  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
+  g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),fileName,relPath);
 }
 
 void LatexGenerator::startDescription() 
@@ -1918,14 +2059,50 @@ void LatexGenerator::endParamList()
   t << "\\end{Desc}" << endl;
 }
 
-void LatexGenerator::startParameterType(bool first,const char *key)
+void LatexGenerator::startParameterList(bool openBracket)
 {
-  if (!first)
+  /* start of ParameterType ParameterName list */
+  if (openBracket) t << "(";
+  t << endl << "\\begin{DoxyParamCaption}" << endl;
+}
+
+void LatexGenerator::endParameterList()
+{
+}
+
+
+void LatexGenerator::startParameterType(bool /*first*/,const char *key)
+{
+  t << "\\item[{";
+  t << key;
+//  if (!first)
+//  {
+//    t << "\\/ " << key << " ";
+//  }
+}
+
+void LatexGenerator::endParameterType()
+{
+  t << "}]";
+}
+
+void LatexGenerator::startParameterName(bool /*oneArgOnly*/)
+{
+  t << "{";
+}
+
+void LatexGenerator::endParameterName(bool last,bool /* emptyList */,bool closeBracket)
+{
+  t << "}" << endl;
+
+  if (last)
   {
-    t << "\\/ " << key << " ";
+    t << "\\end{DoxyParamCaption}" << endl;
+    if (closeBracket) t << ")";
   }
 }
 
+
 void LatexGenerator::printDoc(DocNode *n,const char *langExt)
 {
   LatexDocVisitor *visitor = new LatexDocVisitor(t,*this,langExt,insideTabbing);
@@ -2015,27 +2192,27 @@ void LatexGenerator::escapeMakeIndexChars(const char *s)
 
 void LatexGenerator::startCodeFragment()
 {
-  if (m_prettyCode)
-  {
-    t << endl << endl;
-    t << "\\begin{footnotesize}\\begin{alltt}\n";
-  }
-  else
-  {
+  //if (m_prettyCode)
+  //{
+  //  t << endl << endl;
+  //  t << "\\begin{footnotesize}\\begin{alltt}\n";
+  //}
+  //else
+  //{
     t << "\n\\begin{DoxyCode}\n";
-  }
+  //}
 }
 
 void LatexGenerator::endCodeFragment()
 {
-  if (m_prettyCode)
-  {
-    t << "\\end{alltt}\\end{footnotesize}" << endl; 
-  }
-  else
-  {
+  //if (m_prettyCode)
+  //{
+  //  t << "\\end{alltt}\\end{footnotesize}" << endl; 
+  //}
+  //else
+  //{
     t << "\\end{DoxyCode}\n";
-  }
+  //}
 }
 
 void LatexGenerator::writeLineNumber(const char *ref,const char *fileName,const char *anchor,int l)
