@@ -92,7 +92,9 @@ class ManGenerator : public OutputGenerator
     void endGroupHeader();
     void startMemberSections() {}
     void endMemberSections() {}
-    void startMemberHeader();
+    void startHeaderSection() {}
+    void endHeaderSection() {}
+    void startMemberHeader(const char *);
     void endMemberHeader();
     void insertMemberAlign(bool) {}
     void startMemberSubtitle() {}
@@ -176,6 +178,8 @@ class ManGenerator : public OutputGenerator
     void endPageRef(const char *,const char *) {}
     void startQuickIndices() {}
     void endQuickIndices() {}
+    void writeSplitBar(const char *) {}
+    void writeLogo() {}
     void writeQuickLinks(bool,HighlightedItem) {}
     void startContents() {}
     void endContents() {}
