@@ -171,8 +171,12 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startMemberSections); }
     void endMemberSections()
     { forall(&OutputGenerator::endMemberSections); }
-    void startMemberHeader()
-    { forall(&OutputGenerator::startMemberHeader); }
+    void startHeaderSection()
+    { forall(&OutputGenerator::startHeaderSection); }
+    void endHeaderSection()
+    { forall(&OutputGenerator::endHeaderSection); }
+    void startMemberHeader(const char *anchor)
+    { forall(&OutputGenerator::startMemberHeader,anchor); }
     void endMemberHeader()
     { forall(&OutputGenerator::endMemberHeader); }
     void startMemberSubtitle()
@@ -324,6 +328,10 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startQuickIndices); }
     void endQuickIndices()
     { forall(&OutputGenerator::endQuickIndices); }
+    void writeSplitBar(const char *name)
+    { forall(&OutputGenerator::writeSplitBar,name); }
+    void writeLogo()
+    { forall(&OutputGenerator::writeLogo); }
     void writeQuickLinks(bool compact,HighlightedItem hli)
     { forall(&OutputGenerator::writeQuickLinks,compact,hli); }
     void startContents()
