@@ -22,6 +22,7 @@
 #include "doxygen.h"
 #include "outputgen.h"
 #include "dot.h"
+#include "msc.h"
 #include "util.h"
 #include "rtfstyle.h"
 #include "message.h"
@@ -33,16 +34,16 @@
 //#define DBG_RTF(x) m_t << x
 #define DBG_RTF(x) do {} while(0)
 
-RTFDocVisitor::RTFDocVisitor(QTextStream &t,CodeOutputInterface &ci,
+RTFDocVisitor::RTFDocVisitor(FTextStream &t,CodeOutputInterface &ci,
                              const char *langExt) 
   : DocVisitor(DocVisitor_RTF), m_t(t), m_ci(ci), m_insidePre(FALSE), 
     m_hide(FALSE), m_indentLevel(0), m_lastIsPara(FALSE), m_langExt(langExt)
 {
 }
 
-QString RTFDocVisitor::getStyle(const char *name)
+QCString RTFDocVisitor::getStyle(const char *name)
 {
-  QString n;
+  QCString n;
   n.sprintf("%s%d",name,m_indentLevel);
   StyleData *sd = rtf_Style[n];
   ASSERT(sd!=0);
@@ -109,6 +110,7 @@ void RTFDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Amp:     m_t << "&"; break;
     case DocSymbol::Dollar:  m_t << "$"; break;
     case DocSymbol::Hash:    m_t << "#"; break;
+    case DocSymbol::DoubleColon:  m_t << "::"; break;
     case DocSymbol::Percent: m_t << "%"; break;
     case DocSymbol::Copy:    m_t << "(C)"; break;
     case DocSymbol::Tm:      m_t << "(TM)"; break;
@@ -222,7 +224,7 @@ void RTFDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Aelig:   m_t << "\346"; break;
     case DocSymbol::AElig:   m_t << "\306"; break;
     default:
-                             err("Error: unknown symbol found\n");
+                             err("error: unknown symbol found\n");
   }
   m_lastIsPara=FALSE;
 }
@@ -333,7 +335,7 @@ void RTFDocVisitor::visit(DocVerbatim *s)
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
       Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,s->context(),s->text().latin1(),
+                            ->parseCode(m_ci,s->context(),s->text(),
                                         s->isExample(),s->exampleFile());
       //m_t << "\\par" << endl; 
       m_t << "}" << endl;
@@ -408,7 +410,7 @@ void RTFDocVisitor::visit(DocAnchor *anc)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visit(DocAnchor)}\n");
-  QString anchor;
+  QCString anchor;
   if (!anc->file().isEmpty())
   {
     anchor+=anc->file();
@@ -441,7 +443,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
          FileDef fd( cfi.dirPath(), cfi.fileName() );
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
-                                           inc->text().latin1(),
+                                           inc->text(),
                                            inc->isExample(),
                                            inc->exampleFile(), &fd);
          m_t << "\\par";
@@ -454,7 +456,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
       m_t << rtf_Style_Reset << getStyle("CodeExample");
       Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,inc->context(),
-                                        inc->text().latin1(),inc->isExample(),
+                                        inc->text(),inc->isExample(),
                                         inc->exampleFile());
       m_t << "\\par";
       m_t << "}" << endl;
@@ -497,7 +499,7 @@ void RTFDocVisitor::visit(DocIncOperator *op)
     if (!m_hide) 
     {
       Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,op->context(),op->text().latin1(),
+                            ->parseCode(m_ci,op->context(),op->text(),
                                         op->isExample(),op->exampleFile());
     }
     pushEnabled();
@@ -750,7 +752,7 @@ void RTFDocVisitor::visitPre(DocSection *s)
   if (!m_lastIsPara) m_t << "\\par" << endl;
   m_t << "{{" // start section
       << rtf_Style_Reset;
-  QString heading;
+  QCString heading;
   int level = QMIN(s->level()+1,4);
   heading.sprintf("Heading%d",level);
   // set style
@@ -1017,7 +1019,7 @@ void RTFDocVisitor::visitPre(DocHtmlHeader *header)
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocHtmlHeader)}\n");
   m_t << "{" // start section
       << rtf_Style_Reset;
-  QString heading;
+  QCString heading;
   int level = QMIN(header->level()+2,4);
   heading.sprintf("Heading%d",level);
   // set style
@@ -1080,6 +1082,21 @@ void RTFDocVisitor::visitPost(DocDotFile *)
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocDotFile)}\n");
   popEnabled();
 }
+void RTFDocVisitor::visitPre(DocMscFile *df)
+{
+  DBG_RTF("{\\comment RTFDocVisitor::visitPre(MscDotFile)}\n");
+  writeMscFile(df->file());
+
+  // hide caption since it is not supported at the moment
+  pushEnabled();
+  m_hide=TRUE;
+}
+
+void RTFDocVisitor::visitPost(DocMscFile *) 
+{
+  DBG_RTF("{\\comment RTFDocVisitor::visitPost(MscDotFile)}\n");
+  popEnabled();
+}
 
 void RTFDocVisitor::visitPre(DocLink *lnk)
 {
@@ -1146,7 +1163,7 @@ void RTFDocVisitor::visitPost(DocSecRefList *)
 //void RTFDocVisitor::visitPre(DocLanguage *l)
 //{
 //  DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocLanguage)}\n");
-//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  QCString langId = Config_getEnum("OUTPUT_LANGUAGE");
 //  if (l->id().lower()!=langId.lower())
 //  {
 //    pushEnabled();
@@ -1157,7 +1174,7 @@ void RTFDocVisitor::visitPost(DocSecRefList *)
 //void RTFDocVisitor::visitPost(DocLanguage *l) 
 //{
 //  DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocLanguage)}\n");
-//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  QCString langId = Config_getEnum("OUTPUT_LANGUAGE");
 //  if (l->id().lower()!=langId.lower())
 //  {
 //    popEnabled();
@@ -1191,42 +1208,142 @@ void RTFDocVisitor::visitPre(DocParamSect *s)
   m_t << ":";
   m_t << "\\par";
   m_t << "}" << endl;
-  incIndentLevel();
+  bool useTable = s->type()==DocParamSect::Param ||
+                  s->type()==DocParamSect::RetVal ||
+                  s->type()==DocParamSect::Exception ||
+                  s->type()==DocParamSect::TemplateParam;
+  if (!useTable)
+  {
+    incIndentLevel();
+  }
   m_t << rtf_Style_Reset << getStyle("DescContinue");
   m_lastIsPara=TRUE;
 }
 
-void RTFDocVisitor::visitPost(DocParamSect *)
+void RTFDocVisitor::visitPost(DocParamSect *s)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocParamSect)}\n");
   //m_t << "\\par" << endl;
-  decIndentLevel();
+  bool useTable = s->type()==DocParamSect::Param ||
+                  s->type()==DocParamSect::RetVal ||
+                  s->type()==DocParamSect::Exception ||
+                  s->type()==DocParamSect::TemplateParam;
+  if (!useTable)
+  {
+    decIndentLevel();
+  }
   m_t << "}" << endl;
 }
 
 void RTFDocVisitor::visitPre(DocParamList *pl)
 {
+  static int columnPos[4][5] = 
+  { { 2, 25, 100, 100, 100 }, // no inout, no type
+    { 3, 14,  35, 100, 100 }, // inout, no type
+    { 3, 25,  50, 100, 100 }, // no inout, type
+    { 4, 14,  35, 55,  100 }, // no inout, type
+  };
+  int config=0;
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocParamList)}\n");
 
-  // Put in the direction: in/out/in,out if specified.
-  if (pl->direction()!=DocParamSect::Unspecified)
+  DocParamSect::Type parentType = DocParamSect::Unknown;
+  DocParamSect *sect = 0;
+  if (pl->parent() && pl->parent()->kind()==DocNode::Kind_ParamSect)
   {
-    m_t << "[";
-    if (pl->direction()==DocParamSect::In)
+    parentType = ((DocParamSect*)pl->parent())->type();
+    sect=(DocParamSect*)pl->parent();
+  }
+  bool useTable = parentType==DocParamSect::Param ||
+                  parentType==DocParamSect::RetVal ||
+                  parentType==DocParamSect::Exception ||
+                  parentType==DocParamSect::TemplateParam;
+  if (sect && sect->hasInOutSpecifier()) config+=1;
+  if (sect && sect->hasTypeSpecifier())  config+=2;
+  if (useTable)
+  {
+    int i;
+    m_t << "\\trowd \\trgaph108\\trleft426\\tblind426"
+         "\\trbrdrt\\brdrs\\brdrw10\\brdrcf15 "
+         "\\trbrdrl\\brdrs\\brdrw10\\brdrcf15 "
+         "\\trbrdrb\\brdrs\\brdrw10\\brdrcf15 "
+         "\\trbrdrr\\brdrs\\brdrw10\\brdrcf15 "
+         "\\trbrdrh\\brdrs\\brdrw10\\brdrcf15 "
+         "\\trbrdrv\\brdrs\\brdrw10\\brdrcf15 "<< endl;
+    for (i=0;i<columnPos[config][0];i++)
     {
-      m_t << "in";
+      m_t << "\\clvertalt\\clbrdrt\\brdrs\\brdrw10\\brdrcf15 "
+           "\\clbrdrl\\brdrs\\brdrw10\\brdrcf15 "
+           "\\clbrdrb\\brdrs\\brdrw10\\brdrcf15 "
+           "\\clbrdrr \\brdrs\\brdrw10\\brdrcf15 "
+           "\\cltxlrtb "
+           "\\cellx" << (rtf_pageWidth*columnPos[config][i+1]/100) << endl;
     }
-    else if (pl->direction()==DocParamSect::Out)
+    m_t << "\\pard \\widctlpar\\intbl\\adjustright" << endl;
+  }
+
+  if (sect && sect->hasInOutSpecifier())
+  {
+    if (useTable)
     {
-      m_t << "out";
+      m_t << "{";
     }
-    else if (pl->direction()==DocParamSect::InOut)
+
+    // Put in the direction: in/out/in,out if specified.
+    if (pl->direction()!=DocParamSect::Unspecified)
     {
-      m_t << "in,out";
+      if (pl->direction()==DocParamSect::In)
+      {
+        m_t << "in";
+      }
+      else if (pl->direction()==DocParamSect::Out)
+      {
+        m_t << "out";
+      }
+      else if (pl->direction()==DocParamSect::InOut)
+      {
+        m_t << "in,out";
+      }
     }
-    m_t << "] ";
+
+    if (useTable)
+    {
+      m_t << "\\cell }";
+    }
+  }
+
+  if (sect && sect->hasTypeSpecifier())
+  {
+    if (useTable)
+    {
+      m_t << "{";
+    }
+    QListIterator<DocNode> li(pl->paramTypes());
+    DocNode *type;
+    bool first=TRUE;
+    for (li.toFirst();(type=li.current());++li)
+    {
+      if (!first) m_t << " | "; else first=FALSE;
+      if (type->kind()==DocNode::Kind_Word)
+      {
+        visit((DocWord*)type); 
+      }
+      else if (type->kind()==DocNode::Kind_LinkedWord)
+      {
+        visit((DocLinkedWord*)type); 
+      }
+    }
+    if (useTable)
+    {
+      m_t << "\\cell }";
+    }
+  }
+  
+
+  if (useTable)
+  {
+    m_t << "{";
   }
 
   m_t << "{\\i ";
@@ -1248,14 +1365,41 @@ void RTFDocVisitor::visitPre(DocParamList *pl)
     }
   }
   m_t << "} ";
+
+  if (useTable)
+  {
+    m_t << "\\cell }{";
+  }
   m_lastIsPara=TRUE;
 }
 
-void RTFDocVisitor::visitPost(DocParamList *)
+void RTFDocVisitor::visitPost(DocParamList *pl)
 {
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocParamList)}\n");
-  m_t << "\\par" << endl;
+
+  DocParamSect::Type parentType = DocParamSect::Unknown;
+  DocParamSect *sect = 0;
+  if (pl->parent() && pl->parent()->kind()==DocNode::Kind_ParamSect)
+  {
+    parentType = ((DocParamSect*)pl->parent())->type();
+    sect=(DocParamSect*)pl->parent();
+  }
+  bool useTable = parentType==DocParamSect::Param ||
+                  parentType==DocParamSect::RetVal ||
+                  parentType==DocParamSect::Exception ||
+                  parentType==DocParamSect::TemplateParam;
+  if (useTable)
+  {
+    m_t << "\\cell }" << endl;
+    //m_t << "\\pard \\widctlpar\\intbl\\adjustright" << endl;
+    m_t << "{\\row }" << endl;
+  }
+  else
+  {
+    m_t << "\\par" << endl;
+  }
+
   m_lastIsPara=TRUE;
 }
 
@@ -1269,7 +1413,7 @@ void RTFDocVisitor::visitPre(DocXRefItem *x)
   m_t << "{" << rtf_Style["Heading5"]->reference << endl;
   if (Config_getBool("RTF_HYPERLINKS") && !anonymousEnum)
   {
-    QString refName;
+    QCString refName;
     if (!x->file().isEmpty())
     {
       refName+=x->file();
@@ -1405,11 +1549,11 @@ void RTFDocVisitor::filter(const char *str,bool verbatim)
   }
 }
 
-void RTFDocVisitor::startLink(const QString &ref,const QString &file,const QString &anchor)
+void RTFDocVisitor::startLink(const QCString &ref,const QCString &file,const QCString &anchor)
 {
   if (ref.isEmpty() && Config_getBool("RTF_HYPERLINKS"))
   {
-    QString refName;
+    QCString refName;
     if (!file.isEmpty())
     {
       refName+=file;
@@ -1432,7 +1576,7 @@ void RTFDocVisitor::startLink(const QString &ref,const QString &file,const QStri
   m_lastIsPara=FALSE;
 }
 
-void RTFDocVisitor::endLink(const QString &ref)
+void RTFDocVisitor::endLink(const QCString &ref)
 {
   if (ref.isEmpty() && Config_getBool("RTF_HYPERLINKS"))
   {
@@ -1458,15 +1602,15 @@ void RTFDocVisitor::popEnabled()
   delete v;
 }
 
-void RTFDocVisitor::writeDotFile(const QString &fileName)
+void RTFDocVisitor::writeDotFile(const QCString &fileName)
 {
-  QString baseName=fileName;
+  QCString baseName=fileName;
   int i;
   if ((i=baseName.findRev('/'))!=-1)
   {
     baseName=baseName.right(baseName.length()-i-1);
   } 
-  QString outDir = Config_getString("RTF_OUTPUT");
+  QCString outDir = Config_getString("RTF_OUTPUT");
   writeDotGraphFromFile(fileName,outDir,baseName,BITMAP);
   if (!m_lastIsPara) m_t << "\\par" << endl;
   m_t << "{" << endl;
@@ -1478,15 +1622,15 @@ void RTFDocVisitor::writeDotFile(const QString &fileName)
   m_lastIsPara=TRUE;
 }
 
-void RTFDocVisitor::writeMscFile(const QString &fileName)
+void RTFDocVisitor::writeMscFile(const QCString &fileName)
 {
-  QString baseName=fileName;
+  QCString baseName=fileName;
   int i;
   if ((i=baseName.findRev('/'))!=-1)
   {
     baseName=baseName.right(baseName.length()-i-1);
   } 
-  QString outDir = Config_getString("RTF_OUTPUT");
+  QCString outDir = Config_getString("RTF_OUTPUT");
   writeMscGraphFromFile(fileName,outDir,baseName,MSC_BITMAP);
   if (!m_lastIsPara) m_t << "\\par" << endl;
   m_t << "{" << endl;
