@@ -28,7 +28,7 @@
 #include <qfileinfo.h> 
 #include "parserintf.h"
 
-XmlDocVisitor::XmlDocVisitor(QTextStream &t,CodeOutputInterface &ci) 
+XmlDocVisitor::XmlDocVisitor(FTextStream &t,CodeOutputInterface &ci) 
   : DocVisitor(DocVisitor_XML), m_t(t), m_ci(ci), m_insidePre(FALSE), m_hide(FALSE) 
 {
 }
@@ -76,6 +76,7 @@ void XmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Amp:     m_t << "&amp;"; break;
     case DocSymbol::Dollar:  m_t << "$"; break;
     case DocSymbol::Hash:    m_t << "#"; break;
+    case DocSymbol::DoubleColon: m_t << "::"; break;
     case DocSymbol::Percent: m_t << "%"; break;
     case DocSymbol::Copy:    m_t << "<copy/>"; break;
     case DocSymbol::Tm:      m_t << "<trademark/>"; break;
@@ -101,7 +102,7 @@ void XmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Aelig:   m_t << "<aelig/>"; break;
     case DocSymbol::AElig:   m_t << "<AElig/>"; break;
     default:
-                             err("Error: unknown symbol found\n");
+                             err("error: unknown symbol found\n");
   }
 }
 
@@ -179,7 +180,7 @@ void XmlDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::Code: // fall though
       m_t << "<programlisting>"; 
       Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,s->context(),s->text().latin1(),
+                            ->parseCode(m_ci,s->context(),s->text(),
                                         s->isExample(),s->exampleFile());
       m_t << "</programlisting>"; 
       break;
@@ -237,7 +238,7 @@ void XmlDocVisitor::visit(DocInclude *inc)
          FileDef fd( cfi.dirPath(), cfi.fileName() );
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
-                                           inc->text().latin1(),
+                                           inc->text(),
                                            inc->isExample(),
                                            inc->exampleFile(), &fd);
          m_t << "</programlisting>"; 
@@ -247,7 +248,7 @@ void XmlDocVisitor::visit(DocInclude *inc)
       m_t << "<programlisting>";
       Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,inc->context(),
-                                        inc->text().latin1(),
+                                        inc->text(),
                                         inc->isExample(),
                                         inc->exampleFile());
       m_t << "</programlisting>"; 
@@ -287,7 +288,7 @@ void XmlDocVisitor::visit(DocIncOperator *op)
     {
       Doxygen::parserManager->getParser(m_langExt)
                             ->parseCode(m_ci,op->context(),
-                                        op->text().latin1(),op->isExample(),
+                                        op->text(),op->isExample(),
                                         op->exampleFile());
     }
     pushEnabled();
@@ -656,7 +657,7 @@ void XmlDocVisitor::visitPre(DocImage *img)
   }
   m_t << "\"";
 
-  QString baseName=img->name();
+  QCString baseName=img->name();
   int i;
   if ((i=baseName.findRev('/'))!=-1 || (i=baseName.findRev('\\'))!=-1)
   {
@@ -679,7 +680,7 @@ void XmlDocVisitor::visitPre(DocImage *img)
 
   // copy the image to the output dir
   QFile inImage(img->name());
-  QFile outImage(Config_getString("XML_OUTPUT")+"/"+baseName.ascii());
+  QFile outImage(Config_getString("XML_OUTPUT")+"/"+baseName.data());
   if (inImage.open(IO_ReadOnly))
   {
     if (outImage.open(IO_WriteOnly))
@@ -711,6 +712,17 @@ void XmlDocVisitor::visitPost(DocDotFile *)
   m_t << "</dotfile>" << endl;
 }
 
+void XmlDocVisitor::visitPre(DocMscFile *df)
+{
+  if (m_hide) return;
+  m_t << "<mscfile name=\"" << df->file() << "\">";
+}
+
+void XmlDocVisitor::visitPost(DocMscFile *) 
+{
+  if (m_hide) return;
+  m_t << "</dotfile>" << endl;
+}
 void XmlDocVisitor::visitPre(DocLink *lnk)
 {
   if (m_hide) return;
@@ -810,6 +822,24 @@ void XmlDocVisitor::visitPre(DocParamList *pl)
   DocNode *param;
   for (li.toFirst();(param=li.current());++li)
   {
+    if (pl->paramTypes().count()>0)
+    {
+      QListIterator<DocNode> li(pl->paramTypes());
+      DocNode *type;
+      for (li.toFirst();(type=li.current());++li)
+      {
+        m_t << "<parametertype>";
+        if (type->kind()==DocNode::Kind_Word)
+        {
+          visit((DocWord*)type); 
+        }
+        else if (type->kind()==DocNode::Kind_LinkedWord)
+        {
+          visit((DocLinkedWord*)type); 
+        }
+        m_t << "</parametertype>" << endl;
+      }
+    }
     m_t << "<parametername";
     if (pl->direction()!=DocParamSect::Unspecified)
     {
@@ -907,7 +937,7 @@ void XmlDocVisitor::filter(const char *str)
   m_t << convertToXML(str);
 }
 
-void XmlDocVisitor::startLink(const QString &ref,const QString &file,const QString &anchor)
+void XmlDocVisitor::startLink(const QCString &ref,const QCString &file,const QCString &anchor)
 {
   m_t << "<ref refid=\"" << file;
   if (!anchor.isEmpty()) m_t << "_1" << anchor;
